use snafu::prelude::*;
//use snafu::*;

use crate::config::ConfigError;

#[derive(Debug, Snafu)]
#[snafu(visibility(pub))]
/// The possible error cases
pub enum Error {
    #[snafu(display("{}\nConfiguration file reading or parsing error (see above)", source))]
    Config { source: ConfigError },
    #[snafu(display("{}\nTorrent/magnet reading or parsing error", source))]
    Imdl { source: imdl::error::Error },
    #[snafu(display("{}\nqBittorrent API communication error", source))]
    Api { source: std::io::Error },
    #[snafu(display("{}\nInternal qBittorrent API error", source))]
    InternalApi { source: qbittorrent_web_api::api_impl::Error },
    #[snafu(display("Other error:\n{}", message))]
    Message { message: String },
    //GenericIOError(std::io::Error),
}

impl Error {
  pub fn message(message: impl Into<String>) -> Error {
    Self::Message {
      message: message.into(),
    }
  }
}
